
**************************************************************
************ Preliminaries (Version 07/21/2019) **************
**************************************************************

clear all
set more off
set matsize 10000
set maxvar 12000

** Set directory
cd "${project}/Data"

use grid_rd_SL.dta

*Defining sample for RD figures
gen figure_sample = near_dist_sign_km<150 & near_dist_sign_km>-150 

*Defining conflict measures
local all_conflict = "ln_sum_deadly ln_sum_fatali ln_conflictfm"
local civil_conflict = "ln_civf ln_civfat ln_civfm"
local non_civil_conflict = "ln_noncivf ln_noncivfat ln_noncivfm"
local within_group_conflict = "ln_ethf ln_ethfat ln_ethfm"

*Defining cell-level conntrol set
local rd = "elev simean split_grid"

*Switch to Results folder
cd "${project}/Results"

*************************
******** Table 3 ********
*************************

*Panel A - All Conflicts
foreach var in `all_conflict' {
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode `rd' if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
}
*
*Panel B - Civil Conflicts
foreach var in `civil_conflict' {
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode  if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode `rd' if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
}
*
*Panel C - Non-Civil Conflicts
foreach var in `non_civil_conflict' {
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode  if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode `rd' if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
}
*
*Panel D - Within-Group Conflicts
foreach var in `within_group_conflict' {
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode  if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode `rd' if near_dist<60, cluster(NAME)
outreg2 using Table3.xls, stats(coef se) keep(SL)
}
*

**************************
******** Figure 6 ********
**************************

binscatter ln_sum_deadly near_dist_sign_km if figure_sample==1, rd(0) ytitle(ln(1+Deadly Conflict Incidents)) xtitle(Distance to Border (km)) xlabel(-150 -100 -50 0 50 100 150)
graph export "Figure6a.pdf", replace
binscatter ln_civf near_dist_sign_km if figure_sample==1, rd(0) ytitle(ln(1+Deadly Civil Conflict Incidents)) xtitle(Distance to Border (km)) xlabel(-150 -100 -50 0 50 100 150)
graph export "Figure6b.pdf", replace
binscatter ln_noncivf near_dist_sign_km if figure_sample==1, rd(0) ytitle(ln(1+Deadly Non-Civil Conflict Incidents)) xtitle(Distance to Border (km)) xlabel(-150 -100 -50 0 50 100 150)
graph export "Figure6c.pdf", replace
binscatter ln_ethf near_dist_sign_km if figure_sample==1, rd(0) ytitle(ln(1+Deadly Within-Group Conflict Incidents)) xtitle(Distance to Border (km)) xlabel(-150 -100 -50 0 50 100 150)
graph export "Figure6d.pdf", replace







