**************************************************************
************ Preliminaries (Version 07/21/2019) **************
**************************************************************
clear all
set more off
set matsize 10000
set maxvar 12000

cd "${project}/Data"

use master_SL.dta

*Defining Variables for Balance

local incidents = "ln_conflict_fatal ln_civf ln_noncivf ln_ethf"
local deaths = "log_fatalities ln_civfat ln_noncivfat ln_ethfat"
local duration = "ln_cfatm ln_civmf ln_noncivmf ln_ethmf"

local geo_balance = "Shape_area dist_kilometers SI Maizmean Cassmea PMillmea  Sorgmea Potmea Yammea RFCrst fenske_ecology meanalt  meantemp split10pc TSI sc_mean abs_lat LAT LON coast river rugged_mean"
local eth_balance = "v33 v30 v5 v4 herding ag_intens single_inherit_land prop_rights patrilineal matrilineal  patrilocal matrilocal polygyny cousin_marriage bride_price female_agriculture  "
local hist_balance = "ln_slave_land local_elections active_god city1800  mission_ind rail_ind ln_pdmean60"
local endog_balance = "light10mea llight10mea std_norm10 lstd_norm10 light_growth inequality_growth islam_indicator"

local all_conflict = "ln_conflict_fatal log_fatalities ln_cfatm"
local civil_conflict = "ln_civf ln_civfat ln_civmf"
local non_civil_conflict = "ln_noncivf ln_noncivfat ln_noncivmf"
local within_group_conflict = "ln_ethf ln_ethfat ln_ethmf"

*Defining control variables for analysis

local fe = "i.ccode"
local geo = "ln_shape_area ln_dist_kilometers meanalt SI abs_lat lon split10pc sc_mean"
local hist = "v33 v30 patrilineal"

cd "${project}/Results"

*************************
******** Table 1 ********
*************************

** Panel A: Conflict

foreach var in `incidents' {
reg `var' SL,r
outreg2 using Table1_panelA.xls, stats(coef se mean)
}
*
foreach var in `deaths' {
reg `var' SL,r
outreg2 using Table1_panelA.xls, stats(coef se mean)
}
*
foreach var in `duration' {
reg `var' SL,r
outreg2 using Table1_panelA.xls, stats(coef se mean)
}
*
** Panel B: Geography

foreach var in `geo_balance' {
reg `var' SL,r
outreg2 using Table1_panelB.xls, stats(coef se mean)
}
*

** Panel C: Historical Variables & Ethnicity Characteristics

foreach var in `eth_balance' {
reg `var' SL,r
outreg2 using Table1_panelC.xls, stats(coef se mean)
}
*
foreach var in `hist_balance' {
reg `var' SL,r
outreg2 using Table1_panelC.xls, stats(coef se mean)
}
*

** Panel D: Endogenous Variables

foreach var in `endog_balance' {
reg `var' SL,r
outreg2 using Table1_panelD.xls, stats(coef se mean)
}
**

*************************
******** Table 2 ********
*************************

foreach var in `all_conflict' {
reg `var' SL `fe',r
outreg2 using Table2.xls, stats(coef se) keep(SL)
reg `var' SL `fe' `geo',r
outreg2 using Table2.xls, stats(coef se) keep(SL)
reg `var' SL `fe' `geo' `hist',r
outreg2 using Table2.xls, stats(coef se) keep(SL v33)
}
*
foreach var in `civil_conflict' {
reg `var' SL `fe',r
outreg2 using Table2.xls, stats(coef se) keep(SL)
reg `var' SL `fe' `geo',r
outreg2 using Table2.xls, stats(coef se) keep(SL)
reg `var' SL `fe' `geo' `hist',r
outreg2 using Table2.xls, stats(coef se) keep(SL v33)
}
*
foreach var in `non_civil_conflict' {
reg `var' SL `fe',r
outreg2 using Table2.xls, stats(coef se) keep(SL)
reg `var' SL `fe' `geo',r
outreg2 using Table2.xls, stats(coef se) keep(SL)
reg `var' SL `fe' `geo' `hist',r
outreg2 using Table2.xls, stats(coef se) keep(SL v33)
}
*
foreach var in `within_group_conflict' {
reg `var' SL `fe',r
outreg2 using Table2.xls, stats(coef se) keep(SL)
reg `var' SL `fe' `geo',r
outreg2 using Table2.xls, stats(coef se) keep(SL)
reg `var' SL `fe' `geo' `hist',r
outreg2 using Table2.xls, stats(coef se) keep(SL v33)
}
*

*************************
******** Table 5 ********
*************************

nbreg repeat_1 SL `fe' `geo' `hist', r
outreg2 using Table5.xls, keep(SL)
nbreg not_repeat_1 SL `fe' `geo' `hist', r
outreg2 using Table5.xls, keep(SL)
nbreg repeat_3 SL `fe' `geo' `hist', r
outreg2 using Table5.xls, keep(SL)
nbreg not_repeat_3 SL `fe' `geo' `hist', r
outreg2 using Table5.xls, keep(SL)
nbreg repeat_6 SL `fe' `geo' `hist', r
outreg2 using Table5.xls, keep(SL)
nbreg not_repeat_6 SL `fe' `geo' `hist', r
outreg2 using Table5.xls, keep(SL)

*************************
******** Table 6 ********
*************************

nbreg conflict_0 SL `fe' `geo' `hist', robust
outreg2 using Table6.xls, keep(SL)
nbreg conflict_1 SL `fe' `geo' `hist', robust
outreg2 using Table6.xls, keep(SL)
nbreg conflict_2 SL `fe' `geo' `hist', robust
outreg2 using Table6.xls, keep(SL)
nbreg conflict_large SL `fe' `geo' `hist', robust
outreg2 using Table6.xls, keep(SL)


***********************
****** Figure 3 *******
***********************

reg ln_conflict_fatal SL `fe' `geo' `hist',r
avplot SL, xtitle(e( Segmentary Lineage | X )) ytitle(e(ln(1+Deadly Conflict Incidents)|X)) mlabel(NAME) graphregion(color(white)) lcolor(red)
graph export "Figure3a.pdf", replace
reg ln_civf SL `fe' `geo' `hist',r
avplot SL, xtitle(e( Segmentary Lineage | X )) ytitle(e(ln(1+Deadly Civil Conflict Incidents)|X)) mlabel(NAME) graphregion(color(white)) lcolor(red)
graph export "Figure3b.pdf", replace
reg ln_noncivf SL `fe' `geo' `hist',r
avplot SL, xtitle(e( Segmentary Lineage | X )) ytitle(e(ln(1+Deadly Non-Civil Conflict Incidents)|X)) mlabel(NAME) graphregion(color(white)) lcolor(red)
graph export "Figure3c.pdf", replace
reg ln_ethf SL `fe' `geo' `hist',r
avplot SL, xtitle(e( Segmentary Lineage | X )) ytitle(e(ln(1+Deadly Local Conflict Incidents)|X)) mlabel(NAME) graphregion(color(white)) lcolor(red)
graph export "Figure3d.pdf", replace




 
