*******************************
******** Preliminaries ********
*******************************

clear all
set more off
set matsize 10000
set maxvar 12000

** Set directory

cd "${project}/Data"

use panel_hazard_model.dta

local fe = "i.ccode"
local geo = "ln_shape_area ln_dist_kilometers meanalt SI abs_lat lon split10pc sc_mean"
local hist = "v33 v30 patrilineal"

*Switch to Results folder
cd "${project}/Results"

***************************
******** Table A18 ********
***************************

** Conflict Offset

/* Offset - Hazard*/
preserve
xtset Name YEAR
drop if l.conflict_indicator_hazard==0 & YEAR!=1997
gen conflict_dur2=conflict_dur*conflict_dur
gen conflict_dur3=conflict_dur2*conflict_dur
logit conflict_offset SL conflict_dur conflict_dur2 conflict_dur3 `fe' `geo' `hist' if YEAR!=1997 & v33!=0, cluster(Name)
outreg2 using TableA18.xls, keep(SL)
margins, dydx(SL) atmeans
restore 

/* Civ Offset - Hazard*/
preserve
xtset Name YEAR
drop if l.civ2i==0 & YEAR!=1997
gen civ_conflict_dur2=civ_conflict_dur*civ_conflict_dur
gen civ_conflict_dur3=civ_conflict_dur2*civ_conflict_dur
logit civ2off SL civ_conflict_dur civ_conflict_dur2 civ_conflict_dur3  `fe' `geo' `hist' if YEAR!=1997 & v33!=0, cluster(Name)
outreg2 using TableA18.xls, keep(SL)
margins, dydx(SL) atmeans
restore 

/* Nonciv Offset - Hazard*/
preserve
xtset Name YEAR
drop if l.nonciv2i==0 & YEAR!=1997
gen nonciv_conflict_dur2=nonciv_conflict_dur*nonciv_conflict_dur
gen nonciv_conflict_dur3=nonciv_conflict_dur2*nonciv_conflict_dur
logit nonciv2off SL nonciv_conflict_dur nonciv_conflict_dur2 nonciv_conflict_dur3 `fe' `geo' `hist' if YEAR!=1997 & v33!=0, cluster(Name)
outreg2 using TableA18.xls, keep(SL)
margins, dydx(SL) atmeans
restore

/* Intra Group Offset - Hazard*/
preserve
xtset Name YEAR
drop if l.eth2i==0 & YEAR!=1997
gen eth_conflict_dur2=eth_conflict_dur*eth_conflict_dur
gen eth_conflict_dur3=eth_conflict_dur2*eth_conflict_dur
logit eth2off SL eth_conflict_dur eth_conflict_dur2 eth_conflict_dur3 `fe' `geo' `hist' if YEAR!=1997 & v33!=0, cluster(Name)
outreg2 using TableA18.xls, keep(SL)
margins, dydx(SL) atmeans
restore

** Conflict Onset

/* Onset - Hazard*/
preserve
xtset Name YEAR
drop if l.conflict_indicator_hazard==1 & YEAR!=1997
gen peace_dur2=peace_dur*peace_dur
gen peace_dur3=peace_dur2*peace_dur
logit conflict_onset SL peace_dur peace_dur2 peace_dur3 `fe' `geo' `hist'  if YEAR!=1997 & v33!=0, cluster(Name)
outreg2 using TableA18.xls, keep(SL)
margins, dydx(SL) atmeans
restore 

/* Civ Onset - Hazard*/
preserve
xtset Name YEAR
drop if l.civ2i==1 & YEAR!=1997
gen civ_peace_dur2=civ_peace_dur*civ_peace_dur
gen civ_peace_dur3=civ_peace_dur2*civ_peace_dur
logit civ2on SL civ_peace_dur civ_peace_dur2 civ_peace_dur3  `fe' `geo' `hist'  if YEAR!=1997 & v33!=0, cluster(Name)
outreg2 using TableA18.xls, keep(SL)
margins, dydx(SL) atmeans
restore

/* Nonnonciv Onset - Hazard*/
preserve
xtset Name YEAR
drop if l.nonciv2i==1 & YEAR!=1997
gen nonciv_peace_dur2=nonciv_peace_dur*nonciv_peace_dur
gen nonciv_peace_dur3=nonciv_peace_dur2*nonciv_peace_dur
logit nonciv2on SL nonciv_peace_dur nonciv_peace_dur2 nonciv_peace_dur3 `fe' `geo' `hist'  if YEAR!=1997 & v33!=0, cluster(Name)
outreg2 using TableA18.xls, keep(SL)
margins, dydx(SL) atmeans
restore

/* Intra Group Onset - Hazard*/
preserve
xtset Name YEAR
drop if l.eth2i==1 & YEAR!=1997
gen eth_peace_dur2=eth_peace_dur*eth_peace_dur
gen eth_peace_dur3=eth_peace_dur2*eth_peace_dur
logit eth2on SL eth_peace_dur eth_peace_dur2 eth_peace_dur3 `fe' `geo' `hist'  if YEAR!=1997 & v33!=0, cluster(Name)
outreg2 using TableA18.xls, keep(SL)
margins, dydx(SL) atmeans
restore

 
