**************************************************************
************ Preliminaries (Version 07/21/2019) **************
**************************************************************

clear all
set more off
set matsize 10000
set maxvar 12000

cd "${project}/Data"
use SL_proxy_sample.dta

*** Generate Proxy 

gen clan = v15
gen pat_kin = v17
gen mat_kin = v19 
gen res = v12

lasso2 SL clan#pat_kin#mat_kin#res if census==1
lasso2, lic(ebic)
predict seg_lasso, xb lambda(1)

replace v33 = . if v33==0
replace v30 = . if v30==0

local fe = "i.ccode"
local geo = "ln_shape_area ln_dist_kilometers meanalt SI abslat LON split10pc sc_mean"
local hist = "v33 v30 patrilineal"

local all_conflict = "ln_conflictf ln_conflictfat ln_conflictfm"
local civil_conflict = "ln_civf ln_civfat ln_civfm"
local non_civil_conflict = "ln_noncivf ln_noncivfat ln_noncivfm"
local within_group_conflict = "ln_ethf ln_ethfat ln_ethfm"
local all_conflict_count = "conflictf conflictfat conflictfm"

cd "${project}/Results"

******************************************************
******** Figure A1 - Distribution of SL Proxy ********
******************************************************

hist seg_lasso, bin(7) kdensity xtitle(SL Proxy)
gr export "FigureA1_HistSLProxy.pdf", replace

****************************************************
******** Table A4 - Interpolated SL results ********
****************************************************

** Panels A-D, OLS
foreach var in `all_conflict' `civil_conflict' `non_civil_conflict' `within_group_conflict' {
reg `var' seg_lasso `fe'  , robust
outreg2 using TableA4.xls, keep(seg_lasso)
reg `var' seg_lasso `fe' `geo' , robust
outreg2 using TableA4.xls, keep(seg_lasso)
reg `var' seg_lasso `fe' `geo' `hist', robust
outreg2 using TableA4.xls, keep(seg_lasso)
}
*
** Panel E, Negative binomial
foreach var in `all_conflict_count'  {
nbreg `var' seg_lasso `fe'  , robust
outreg2 using TableA4.xls, keep(seg_lasso)
nbreg `var' seg_lasso `fe' `geo' , robust
outreg2 using TableA4.xls, keep(seg_lasso)
nbreg `var' seg_lasso `fe' `geo' `hist', robust
outreg2 using TableA4.xls, keep(seg_lasso)
}
*

