
**************************************************************
************ Preliminaries (Version 07/21/2019) **************
**************************************************************

**** This .do file replicates all Appendix table that rely on the baseline grid-cell level RD sample. 

clear all
set more off
set matsize 10000
set maxvar 12000

** Set directory
cd "${project}/Data"

use grid_rd_SL.dta

*Define sample for RD figures
gen figure_sample = near_dist_sign_km<150 & near_dist_sign_km>-150 

*Defining groups of conflict outcomes
local all_conflict = "ln_sum_deadly ln_sum_fatali ln_conflictfm"
local all_conflict_count = "sum_deadly sum_fatali conflictfm"
local precise_conflicts = "lconflictfp lcivfp lnoncivfp lethfp lconflictfatp lcivfatp lnoncivfatp lethfatp lconflictfmp lcivfmp lnoncivfmp lethfmp"

*Definning groups of covariates 
local rd = "elev simean split_grid"
local observables = "rugged ln_elev slope temp water cereal_suit crop_use petrol diamondd mission railwayi explorer"
local baseline_fe = "i.pair_fe i.countrycode"
local lat_lon_group_quad = "lat_group* lon_group* lat2_group* lon2_group* lat_lon_group*"
local lat_lon_pair_quad = "lat_pair* lon_pair* lat2_pair* lon2_pair* lat_lon_pair*"

*Switch to Results folder
** Set directory
cd "${project}/Results"

******************************************************
****** Table A14 - Additional RD Specifications ******
******************************************************

*Panel A: Linear Running Variable in Euclidean Distance
foreach var in `all_conflict' {
forvalues i = 100 80 : 60 {
reg `var' SL near_dist_sign near_dist_sign_seg `baseline_fe' if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*
*Panel B: Negative Binomial Estimates, Linear Running Variable in Euclidean Distance
foreach var in `all_conflict_count' {
forvalues i = 100 80 : 60 {
nbreg `var' SL near_dist_sign near_dist_sign_seg i.pair_fe if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*
*Panel C: Poisson Estimates, Linear Running Variable in Euclidean Distance
foreach var in `all_conflict_count' {
forvalues i = 100 80 : 60 {
poisson `var' SL near_dist_sign near_dist_sign_seg i.pair_fe if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*
*Panel D: Linear Running Variable in Euclidean Distance that Varies at the Contiguous Group Level
foreach var in `all_conflict' {
forvalues i = 100 80 : 60 {
reg `var' SL dist_group* `baseline_fe' if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*
*Panel E: Linear Running Variable in Lat & Lon that Varies at the Contiguous Group Level
foreach var in `all_conflict' {
forvalues i = 100 80 : 60 {
reg `var' SL lat_group* lon_group* `baseline_fe' if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*
*Panel F: Quadratic Running Variable in Lat & Lon that Varies at the Contiguous Group Level
foreach var in `all_conflict' {
forvalues i = 100 80 : 60 {
reg `var' SL `lat_lon_group_quad' `baseline_fe' if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*
*Panel G: Linear Running Variable in Euclidean Distance that Varies at the Pair Level
foreach var in `all_conflict' {
forvalues i = 100 80 : 60 {
reg `var' SL dist_pair* `baseline_fe' if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*
*Panel H: Linear Running Variable in Lat & Lon that Varies at the Pair Level
foreach var in `all_conflict' {
forvalues i = 100 80 : 60 {
reg `var' SL lat_pair* lon_pair* `baseline_fe' if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*
*Panel I: Quadratic Running Variable in Lat & Lon that Varies at the Pair Level
foreach var in `all_conflict' {
forvalues i = 100 80 : 60 {
reg `var' SL `lat_lon_pair_quad' `baseline_fe' if near_dist<`i', cluster(NAME)
outreg2 using TableA14.xls, keep(SL)
}
}
*

**************************************************
****** Table A15 - High Precision Conflicts ******
**************************************************

foreach var in `precise_conflicts' {
reg `var' SL i.pair_fe near_dist_sign near_dist_sign_seg i.countrycode `rd' if near_dist<60, cluster(NAME)
outreg2 using TableA15.xls, keep(SL)
}
*

****************************************************
****** Table A16 - Observable Characteristics ******
****************************************************

foreach var in `observables' {
reg `var' SL near_dist_sign near_dist_sign_seg `baseline_fe' if near_dist<60, cluster(NAME)
outreg2 using TableA16.xls, keep(SL)
}
*

************************************************
****** Figure A3 - RD Partial Correlation ******
************************************************

binscatter ln_sum_deadly near_dist_sign_km if figure_sample==1, rd(0) ytitle(ln(1+Deadly Conflict Incidents)) xtitle(Distance to Border (km)) xlabel(-150 -100 -50 0 50 100 150) controls(i.pair_fe i.countrycode)
graph export "FigureA3a.pdf", replace
binscatter ln_civf near_dist_sign_km if figure_sample==1, rd(0) ytitle(ln(1+Deadly Civil Conflict Incidents)) xtitle(Distance to Border (km)) xlabel(-150 -100 -50 0 50 100 150) controls(i.pair_fe i.countrycode)
graph export "FigureA3b.pdf", replace
binscatter ln_noncivf near_dist_sign_km if figure_sample==1, rd(0) ytitle(ln(1+Deadly Non-Civil Conflict Incidents)) xtitle(Distance to Border (km)) xlabel(-150 -100 -50 0 50 100 150) controls(i.pair_fe i.countrycode)
graph export "FigureA3c.pdf", replace
binscatter ln_ethf near_dist_sign_km if figure_sample==1, rd(0) ytitle(ln(1+Deadly Within-Group Conflict Incidents)) xtitle(Distance to Border (km)) xlabel(-150 -100 -50 0 50 100 150) controls(i.pair_fe i.countrycode)
graph export "FigureA3d.pdf", replace
