**************************************************************
************ Preliminaries (Version 07/21/2019) **************
**************************************************************

**** This .do file replicates all Appendix table that rely on the baseline cross-ethnic group sample. 
**** This includes Tables A3, A5, A6, A8, A9, A10, A11, A12, A18. 

clear all
set more off
set matsize 10000
set maxvar 12000

** Set directory
cd "${project}/Data"

use master_SL.dta

local all_conflict = "ln_conflict_fatal log_fatalities ln_cfatm"
local civil_conflict = "ln_civf ln_civfat ln_civmf"
local non_civil_conflict = "ln_noncivf ln_noncivfat ln_noncivmf"
local within_group_conflict = "ln_ethf ln_ethfat ln_ethmf"

local incidents = "ln_conflict_fatal ln_civf ln_noncivf ln_ethf"
local deaths = "log_fatalities ln_civfat ln_noncivfat ln_ethfat"
local duration = "ln_cfatm ln_civmf ln_noncivmf ln_ethmf"

*Defining control variables for analysis

local fe = "i.ccode"
local geo = "ln_shape_area ln_dist_kilometers meanalt SI abs_lat lon split10pc sc_mean"
local hist = "v33 v30 patrilineal"


*****************************************
****** Table A3 - Index Components ******
*****************************************

*Merging on index components for non-SL societies
merge 1:1 NAME using tribes_codes_disagg_data.dta
drop _merge
*SL societies have all 3 components
replace lineage = 1 if SL==1
replace lineage_political = 1 if SL==1
replace lineage_geography = 1 if SL==1

cd "${project}/Results"

foreach var in `all_conflict' {
reg `var' `fe' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe')
reg `var' `fe' `geo' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe' `geo')
reg `var' `fe' `geo' `hist' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe' `geo' `hist')
}
*
foreach var in `civil_conflict' {
reg `var' `fe' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe')
reg `var' `fe' `geo' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe' `geo')
reg `var' `fe' `geo' `hist' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe' `geo' `hist')
}
*
foreach var in `non_civil_conflict' {
reg `var' `fe' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe')
reg `var' `fe' `geo' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe' `geo')
reg `var' `fe' `geo' `hist' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe' `geo' `hist')
}
*
foreach var in `within_group_conflict' {
reg `var' `fe' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe')
reg `var' `fe' `geo' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe' `geo')
reg `var' `fe' `geo' `hist' lineage#lineage_political#lineage_geography,r
outreg2 using TableA3.xls, drop(`fe' `geo' `hist')
}
*

******************************************************
****** Table A5 - Alternative Conflict Measures ******
******************************************************

*Conflicts matched using ethnicity name in ACLED actor / conflict description

reg lconflict_nmatch SL `fe' `geo' `hist',r
outreg2 using TableA5.xls, keep(SL)
reg lfatalities_nmatch SL `fe' `geo' `hist',r
outreg2 using TableA5.xls, keep(SL)
reg lmonths_nmatch SL `fe' `geo' `hist',r
outreg2 using TableA5.xls, keep(SL)

*UDCP GED Conflict

reg ln_UCDP_GED SL `fe' `geo' `hist',r
outreg2 using TableA5.xls, keep(SL)
reg ln_UCDP_GED_fatalities SL `fe' `geo' `hist',r
outreg2 using TableA5.xls, keep(SL)
reg ln_UCDP_GED_duration SL `fe' `geo' `hist',r
outreg2 using TableA5.xls, keep(SL)


**********************************************
****** Table A6 - Pre-Colonial Conflict ******
**********************************************

cd "${project}/Data"

**Merge on Jacques conflict data
merge 1:1 NAME using jacques_by_tribe.dta
drop if _merge==2
drop _merge
replace conflict_ind_jacques = 0 if conflict_ind_jacques==.
replace conflict_jacques = 0 if conflict_jacques==.
replace years_of_conflict_jacques = 0 if years_of_conflict_jacques==.

cd "${project}/Results"

reg ln_conflict_fatal SL conflict_ind_jacques `fe' `geo' `hist', robust
outreg2 using TableA6.xls, keep(SL conflict_ind_jacques)
reg ln_conflict_fatal SL conflict_jacques `fe' `geo' `hist', robust
outreg2 using TableA6.xls, keep(SL conflict_jacques)
reg ln_conflict_fatal SL years_of_conflict_jacques `fe' `geo' `hist', robust
outreg2 using TableA6.xls, keep(SL years_of_conflict_jacques)
reg ln_conflict_fatal SL precondum `fe' `geo' `hist' , robust
outreg2 using TableA6.xls, keep(SL precondum)
reg ln_conflict_fatal SL precondum conflict_ind_jacques `fe' `geo' `hist' , robust
outreg2 using TableA6.xls, keep(SL precondum conflict_ind_jacques)

*******************************************
****** Table A7 - Restricted Samples ******
*******************************************

*Panel A: Excluding High Cook's Distance
foreach var in `all_conflict' {
reg `var' SL `fe' `geo' `hist' 
predict dconf, cooksd
reg `var' SL `fe' `geo' `hist' if dconf<4/141, robust
outreg2 using TableA7_PanelA.xls, keep(SL)
drop dconf
}
*
foreach var in `civil_conflict' {
reg `var' SL `fe' `geo' `hist' 
predict dconf, cooksd
reg `var' SL `fe' `geo' `hist' if dconf<4/141, robust
outreg2 using TableA7_PanelA.xls, keep(SL)
drop dconf
}
*
foreach var in `non_civil_conflict' {
reg `var' SL `fe' `geo' `hist' 
predict dconf, cooksd
reg `var' SL `fe' `geo' `hist' if dconf<4/141, robust
outreg2 using TableA7_PanelA.xls, keep(SL)
drop dconf
}
*
foreach var in `within_group_conflict' {
reg `var' SL `fe' `geo' `hist' 
predict dconf, cooksd
reg `var' SL `fe' `geo' `hist' if dconf<4/141, robust
outreg2 using TableA7_PanelA.xls, keep(SL)
drop dconf
}
*

*Panel B: Excluding Top 5% Outcome

* JCY:
*gen civmf = exp(ln_civmf) - 1
*gen noncivmf = exp(ln_noncivmf) - 1
*gen ethmf = exp(ln_ethmf) - 1

reg ln_conflict_fatal SL `fe' `geo' `hist' if conflict_fatal<299, robust
outreg2 using TableA7_PanelB.xls, keep(SL)
reg log_fatalities SL `fe' `geo' `hist' if fatalities<5277, robust
outreg2 using TableA7_PanelB.xls, keep(SL)
reg ln_cfatm SL `fe' `geo' `hist' if  cfatm<85, robust
outreg2 using TableA7_PanelB.xls, keep(SL)

reg ln_civf SL `fe' `geo' `hist' if  civf<240, robust
outreg2 using TableA7_PanelB.xls, keep(SL)
reg ln_civfat SL `fe' `geo' `hist' if  civfat<5220 , robust
outreg2 using TableA7_PanelB.xls, keep(SL)
reg ln_civmf SL `fe' `geo' `hist' if  civmf<64, robust
outreg2 using TableA7_PanelB.xls, keep(SL)

reg ln_noncivf SL `fe' `geo' `hist' if noncivf<129, robust
outreg2 using TableA7_PanelB.xls, keep(SL)
reg ln_noncivfat SL `fe' `geo' `hist' if noncivfat<1252, robust
outreg2 using TableA7_PanelB.xls, keep(SL)
reg ln_noncivmf SL `fe' `geo' `hist' if  noncivmf<59, robust
outreg2 using TableA7_PanelB.xls, keep(SL)

reg ln_ethf SL `fe' `geo' `hist' if  ethf<45, robust
outreg2 using TableA7_PanelB.xls, keep(SL)
reg ln_ethfat SL `fe' `geo' `hist' if  ethfat<728, robust
outreg2 using TableA7_PanelB.xls, keep(SL)
reg ln_ethmf SL `fe' `geo' `hist' if  ethmf<27, robust
outreg2 using TableA7_PanelB.xls, keep(SL)

*Panel C: Excluding Low Precision Conflicts

reg lconflictfp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)
reg lconflictfatp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)
reg lconflictfmp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)

reg lcivfp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)
reg lcivfatp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)
reg lcivfmp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)

reg lnoncivfp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)
reg lnoncivfatp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)
reg lnoncivfmp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)

reg lethfp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)
reg lethfatp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)
reg lethfmp SL `fe' `geo' `hist', robust
outreg2 using TableA7_PanelC.xls,  keep(SL)

*


**************************************************
****** Table A8 - Nearest Neighbor Matching ******
**************************************************

*Column 1 - Matching on geography
foreach var in `incidents' {
teffects nnmatch (`var' lat lon) (SL), atet vce(robust)
outreg2 using TableA8.xls
}
*
foreach var in `deaths' {
teffects nnmatch (`var' lat lon) (SL), atet vce(robust)
outreg2 using TableA8.xls
}
*
foreach var in `duration' {
teffects nnmatch (`var' lat lon) (SL), atet vce(robust)
outreg2 using TableA8.xls
}
*
*Column 2 - Matching on all controls
foreach var in `incidents' {
teffects nnmatch (`var'  `geo' `hist') (SL), atet vce(robust)
outreg2 using TableA8.xls
}
*
foreach var in `deaths' {
teffects nnmatch (`var'  `geo' `hist') (SL), atet vce(robust)
outreg2 using TableA8.xls
}
*
foreach var in `duration' {
teffects nnmatch (`var'  `geo' `hist') (SL), atet vce(robust)
outreg2 using TableA8.xls
}
*
*Column 3 - Matching on all controls, jurisd. hierarchy exact match - 1 group has v33==5 and so cannot be included
foreach var in `incidents' {
teffects nnmatch (`var'  `geo' `hist') (SL) if v33<5, atet ematch(v33) vce(robust) 
outreg2 using TableA8.xls
}
*
foreach var in `deaths' {
teffects nnmatch (`var' `geo' `hist') (SL) if v33<5, atet ematch(v33) vce(robust) 
outreg2 using TableA8.xls
}
*
foreach var in `duration' {
teffects nnmatch (`var' `geo' `hist') (SL) if v33<5, atet ematch(v33) vce(robust) 
outreg2 using TableA8.xls
}
*

**************************************
****** Table A9 - Count Models ******
**************************************

poisson conflict_fatal SL `fe' `geo' `hist',r
outreg2 using TableA9.xls, stats(coef se) keep(SL)
poisson fatalities SL `fe' `geo' `hist',r
outreg2 using TableA9.xls, stats(coef se) keep(SL)
poisson cfatm SL `fe' `geo' `hist',r
outreg2 using TableA9.xls, stats(coef se) keep(SL)

nbreg conflict_fatal SL `fe' `geo' `hist',r
outreg2 using TableA9.xls, stats(coef se) keep(SL)
nbreg fatalities SL `fe' `geo' `hist',r
outreg2 using TableA9.xls, stats(coef se) keep(SL)
nbreg cfatm SL `fe' `geo' `hist',r
outreg2 using TableA9.xls, stats(coef se) keep(SL)


******************************************************
****** Table A10 - Heterogeneity- Country Level ******
******************************************************

cd "${project}/Data"
gen country = cntry_name
merge m:1 country using country_vars.dta, force
keep if _merge==3
drop _merge
** Coded from Garcia-Ponce & Wantchekon
gen rural_indep = 0
replace rural_indep = 1 if (isocode=="MAR" | isocode=="DZA" | isocode=="LBY" | isocode=="CAF" | isocode=="TCD" | isocode=="SDN" | isocode=="CMR" | isocode=="ERI" | isocode=="ETH" | isocode=="SOM" | isocode=="KEN" | isocode=="UGA" | isocode=="MDG" | isocode=="MOZ" | isocode=="ZWE" | isocode=="NAM" | isocode=="AGO"| isocode=="LSO" | isocode=="RWA" | isocode=="BDI" | isocode=="BFA" | isocode=="GMB" | isocode=="GNB")						

*Construct interactions and transform so all variables go in the same direction
gen seg_polity = SL*polity
gen seg_gdp = SL*ln_maddison
gen seg_frac = SL*ethnic_fractionalization
gen seg_legor_uk = SL*legor_uk
gen seg_colony_uk = SL*colony1
gen seg_rural_indep = SL*rural_indep
gen polity_scale = polity+10
gen seg_polity_sc = SL*polity_scale
gen eth_sc = 1-ethnic_frac
gen seg_frac_sc = SL*eth_sc
gen rl_sc = RL_2000 + 2.275151
gen seg_rl_sc = SL*rl_sc

cd "${project}/Results"

reg ln_conflict_fatal SL seg_legor_uk legor_uk  `fe' `geo' `hist', robust
outreg2 using TableA10.xls, keep(SL seg_legor_uk legor_uk)
reg ln_conflict_fatal SL seg_colony_uk colony1 `fe' `geo' `hist', robust
outreg2 using TableA10.xls, keep(SL seg_colony_uk colony1)
reg ln_conflict_fatal SL seg_rural_indep  rural_indep `fe' `geo' `hist', robust
outreg2 using TableA10.xls, keep(SL seg_rural_indep  rural_indep)
reg ln_conflict_fatal SL seg_gdp  ln_maddison `fe' `geo' `hist', robust
outreg2 using TableA10.xls, keep(SL seg_gdp  ln_maddison)
reg ln_conflict_fatal SL seg_polity_sc polity_scale `fe' `geo' `hist', robust
outreg2 using TableA10.xls, keep(SL seg_polity_sc polity_scale)
reg ln_conflict_fatal SL seg_rl_sc rl_sc  `fe' `geo' `hist', robust
outreg2 using TableA10.xls, keep(SL seg_rl_sc rl_sc)
reg ln_conflict_fatal SL seg_frac_sc eth_sc  `fe' `geo' `hist', robust
outreg2 using TableA10.xls, keep(SL seg_frac_sc eth_sc)


********************************************************
****** Table A11 - Heterogeneity- Ethnicity Level ******
********************************************************

*Construct interactions and transform so all variables go in the same direction
gen seg_slave = SL*ln_slave_land
gen seg_split = SL*split10pc
gen seg_elections = SL*local_elections
gen seg_islam = SL*islam_indicator
gen seg_state = SL*v33
gen seg_capital = SL*capital
ge lights_top_half = 0
replace lights_top_half = 1 if ln_lights_pop> -6.312585 
ge seg_lights_top =  SL*lights_top_half
gen seg_mission = SL*mission_ind
gen seg_rail = SL*rail_ind
gen seg_pet = SL*petroleum
gen seg_diamond = SL*diamondd

*Pre-Colonial Measures
reg ln_conflict_fatal SL seg_slave ln_slave_land `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_slave ln_slave_land)
reg ln_conflict_fatal SL seg_state v33 `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_state v33)
reg ln_conflict_fatal SL seg_elections local_elections `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_elections local_elections)
*Colonial Measures
reg ln_conflict_fatal SL seg_split split10pc `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_split split10pc)
reg ln_conflict_fatal SL seg_mission mission_ind   `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_mission mission_ind)
reg ln_conflict_fatal SL seg_rail  rail_ind  `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_rail  rail_ind)
*Contemporary Measures
reg ln_conflict_fatal SL seg_islam islam_indicator `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_islam islam_indicator)
reg ln_conflict_fatal SL seg_lights_top lights_top_half `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_lights_top lights_top_half)
reg ln_conflict_fatal SL seg_capital capital `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_capital capital)
reg ln_conflict_fatal SL seg_diamond  diamondd  `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_diamond  diamondd)
reg ln_conflict_fatal SL seg_pet petroleum   `fe' `geo' `hist', robust
outreg2 using TableA11.xls, keep(SL seg_pet petroleum)

******************************************************************
****** Table A17 - Retaliatory vs. Non-Retaliatory Conflict ******
******************************************************************

preserve
gen type_1 = repeat_1
gen type_2 = not_repeat_1
reshape long type_, i(NAME) j(type)
gen retal = 0
replace retal = 1 if type==1
gen SL_retal = SL*retal
foreach var in `geo' `hist' {
gen retal_control_`var' = retal*`var'
}
*
encode NAME, gen(name_code)
nbreg type_ SL_retal i.name_code retal retal_control_*, cluster(NAME)
outreg2 using TableA17.xls, keep(SL_retal)
restore

preserve
gen type_1 = repeat_3
gen type_2 = not_repeat_3
reshape long type_, i(NAME) j(type)
gen retal = 0
replace retal = 1 if type==1
gen SL_retal = SL*retal
foreach var in `geo' `hist' {
gen retal_control_`var' = retal*`var'
}
*
encode NAME, gen(name_code)
nbreg type_ SL_retal i.name_code retal retal_control_*, cluster(NAME)
outreg2 using TableA17.xls, keep(SL_retal)
restore

preserve
gen type_1 = repeat_6
gen type_2 = not_repeat_6
reshape long type_, i(NAME) j(type)
gen retal = 0
replace retal = 1 if type==1
gen SL_retal = SL*retal
foreach var in `geo' `hist' {
gen retal_control_`var' = retal*`var'
}
*
encode NAME, gen(name_code)
nbreg type_ SL_retal i.name_code retal retal_control_*, cluster(NAME)
outreg2 using TableA17.xls, keep(SL_retal)
restore

